﻿using System;
using System.Web.UI.WebControls;
using System.Data;
using System.Drawing;
using OrgChart.Core;

public partial class Demo2 : System.Web.UI.Page
{



    #region methods to create a random test DataTable

    private void addRow(DataTable data, int uniqueId, int managerId, string name)
    {
        DataRow r = data.NewRow();
        r["UniqueId"] = uniqueId;
        r["ManagerId"] = managerId;
        r["NodeName"] = name;
        data.Rows.Add(r);
    }

    protected DataTable Data
    {
        get
        {
            DataTable data = Session["Demo2"] as DataTable;

            if (data == null)
            {
                data = new DataTable("A table of data");

                data.Columns.Add("UniqueId", typeof(int));
                data.Columns.Add("ManagerId", typeof(int));
                data.Columns.Add("NodeName", typeof(string));

                addRow(data, 1, 0, "RootNode");

                Random randomManager = new Random(DateTime.Now.Millisecond);
                for (int i = 2; i < 5; i++)
                {
                    addRow(data, i, randomManager.Next(1, data.Rows.Count), "Node-" + i);
                }

                Session["Demo2"] = data;

            }
            return data;
        }
        set
        {
            Session["Demo2"] = value;
        }
    }


    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        // Bind the chart to a data source
        DataChart.DataSource = Data;
        // Hook up the ItemDataBound event
        DataChart.ItemDataBound += new OrganisationChartItemEventHandler(ItemDataBound);
        // Display the chart
        DataChart.DataBind();
    }

    /// <summary>
    /// This event handler is invoked once per chart item after the item is data bound.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    void ItemDataBound(object sender, OrganisationChartItemEventArgs e)
    {        
        Label l = e.Item.FindControl("Label1") as Label;
        // Find the number of children from the Item object.  
        // And set the colour of the label accordingly. 
        switch (e.Item.NumberOfChildren)
        {
            case 0: l.BackColor = Color.Gainsboro; break;
            case 1: l.BackColor = Color.Blue; break;
            case 2: l.BackColor = Color.Green; break;
            case 3: l.BackColor = Color.Red; break;
            default: l.BackColor = Color.Gold; break;
        }       
    }

    /// <summary>
    /// This method is called by the Add button created by the DetailedTemplate
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnAdd_Click(object sender, EventArgs e)
    {
        Button s = (Button)sender;
        // Create a new row and add it to the data source.
        int managerId = int.Parse(s.CommandArgument);
        int newId = Data.Rows.Count + 1;

        addRow(Data, newId, managerId, "New Node" + newId);
        DataChart.DataBind();
    }

    protected void btnRemove_Click(object sender, EventArgs e)
    {
        Button s = (Button)sender;
        int managerId = int.Parse(s.CommandArgument);

        // NOTE : This is probably not the best way of deleting from a DataTable.
        for (int idx = 0; idx < Data.Rows.Count; idx++)
        {
            if (Convert.ToInt32(Data.Rows[idx]["UniqueId"]) == managerId)
            {
                Data.Rows[idx].Delete();
                break;
            }
        }

        DataChart.DataBind();
    }

    protected void Button3_Click1(object sender, EventArgs e)
    {
        // Reset the demo
        Data = null;
        DataChart.DataSource = Data;
        DataChart.DataBind();
    }
}
